@@ -9,7 +9,10 @@ Modules exported by this package:
 - `html`: gets html files from a project folder, gets the HTML code
           from files, gets number of a particular element in a file
           or folder, gets elements as tags, and much more.
+- `ux_tools`: gets readability stats for paragraphs of text (could
+          be from just `p` tags or a list of other tags e.g. `li`,
+          `div`, etc.).
 - `validator`: sends HTML or CSS code to the W3C Validator to check
           for errors.
 """
-__version__ = "0.3.7"
+__version__ = "0.5.3"
